==> libreoffice_7.3.2.orig.tar.xz: libreoffice-7.3.2.2/qadevOOo/tests/java/ifc/text/_PrintSettings.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package ifc.text;

import lib.MultiPropertyTest;

/**
* Testing <code>com.sun.star.text.PrintSettings</code>
* service properties :
* <ul>
*  <li><code> PrintGraphics</code></li>
*  <li><code> PrintTables</code></li>
*  <li><code> PrintDrawings</code></li>
*  <li><code> PrintLeftPages</code></li>
*  <li><code> PrintRightPages</code></li>
*  <li><code> PrintControls</code></li>
*  <li><code> PrintReversed</code></li>
*  <li><code> PrintPaperFromSetup</code></li>
*  <li><code> PrintFaxName</code></li>
*  <li><code> PrintAnnotationMode</code></li>
*  <li><code> PrintProspect</code></li>
*  <li><code> PrintPageBackground</code></li>
*  <li><code> PrintBlackFonts</code></li>
* </ul> <p>
* Properties testing is automated by <code>lib.MultiPropertyTest</code>.
* @see com.sun.star.text.PrintSettings
*/
public class _PrintSettings extends MultiPropertyTest {

}

==> libreoffice-25.2.7.1.tar.xz: libreoffice-25.2.7.1/qadevOOo/tests/java/ifc/text/_PrintSettings.java <==
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

package ifc.text;

import lib.MultiPropertyTest;

/**
* Testing <code>com.sun.star.text.PrintSettings</code>
* service properties :
* <ul>
*  <li><code> PrintGraphics</code></li>
*  <li><code> PrintTables</code></li>
*  <li><code> PrintDrawings</code></li>
*  <li><code> PrintLeftPages</code></li>
*  <li><code> PrintRightPages</code></li>
*  <li><code> PrintControls</code></li>
*  <li><code> PrintReversed</code></li>
*  <li><code> PrintPaperFromSetup</code></li>
*  <li><code> PrintFaxName</code></li>
*  <li><code> PrintAnnotationMode</code></li>
*  <li><code> PrintProspect</code></li>
*  <li><code> PrintPageBackground</code></li>
*  <li><code> PrintBlackFonts</code></li>
* </ul> <p>
* Properties testing is automated by <code>lib.MultiPropertyTest</code>.
* @see com.sun.star.text.PrintSettings
*/
public class _PrintSettings extends MultiPropertyTest {

    /**
    * This property returns always true.
    */
    public void _PrintTables() {
        testProperty("PrintTables", new PropertyTester() {
            @Override
            protected Object getNewValue(String p, Object old) {
                return Boolean.TRUE;
            }
        }) ;
    }

    /**
    * This property returns always false.
    */
    public void _PrintReversed() {
        testProperty("PrintReversed", new PropertyTester() {
            @Override
            protected Object getNewValue(String p, Object old) {
                return Boolean.FALSE;
            }
        }) ;
    }


}
